DrivingAnnotation class abstract final

The annotation that is displayed on the map.

Implemented types

Constructors

DrivingAnnotation(DrivingAction action, String? toponym, String descriptionText, DrivingActionMetadata? actionMetadata, List<DrivingLandmark> landmarks, List<DrivingToponymPhrase> toponymPhrase)
factory

Properties

action → DrivingAction
Driver action.
no setter
actionMetadata → DrivingActionMetadata?
Action metadata.
no setter
descriptionText → String
Description text to display.
no setter
hashCode → int
The hash code for this object.
no setteroverride
landmarks → List<DrivingLandmark>
Significant landmarks.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toponym → String?
The toponym of the location.
no setter
toponymPhrase → List<DrivingToponymPhrase>
Toponym phrases with positions for pronunciation.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingAnnotation other) → bool
The equality operator.
override