AddressBook class abstract final

Implemented types

Constructors

AddressBook(AddressRecord? home, AddressRecord? work, List<AddressRecord> favorites, List<AddressCollection> customCollections)
factory

Properties

customCollections → List<AddressCollection>
no setter
favorites → List<AddressRecord>
no setter
hashCode → int
The hash code for this object.
no setteroverride
home → AddressRecord?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
work → AddressRecord?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant AddressBook other) → bool
The equality operator.
override