AddressBookManager class abstract

Implemented types

Constructors

AddressBookManager()

Properties

addressBook AddressBook
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(AddressBookListener addressBookListener) → void
The class does not retain the object in the 'addressBookListener' parameter. It is your responsibility to maintain a strong reference to the target object while it is attached to a class.
isValid() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(AddressBookListener addressBookListener) → void
The class does not retain the object in the 'addressBookListener' parameter. It is your responsibility to maintain a strong reference to the target object while it is attached to a class.
requestRefresh() → void
Request to attempt to get address book from server. Refresh attempts may be throttled and ignored. Immediately after downloading from disk, the first attempt to update will be made automatically.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited