AddressCollection class abstract final

Implemented types

Constructors

AddressCollection(String title, String? description, List<AddressRecord> records)
factory

Properties

description String?
no setter
hashCode int
The hash code for this object.
no setteroverride
records List<AddressRecord>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(covariant AddressCollection other) bool
The equality operator.
override