AddressRecord class abstract final

Implemented types

Constructors

AddressRecord(String title, String? description, String? comment, String? address, Geometry? geometry, String? uri)
factory

Properties

address → String?
no setter
comment → String?
no setter
description → String?
no setter
geometry → Geometry?
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
no setter
uri → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant AddressRecord other) → bool
The equality operator.
override