ArrowStyle class abstract

Implemented types

Constructors

ArrowStyle()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFillColor(Color fillColor) → void
Fill color of the arrow. Default: RGBA 0xFFFFFFFF.
setLength({StylingProportionFunction length = const mapkit_styling_proportion_function.StylingProportionFunction.fromFloat(90.0)}) → void
Overall length of the arrow (including the tip) in units. Default: 90
setMinZoomVisible(double? minZoom) → void
Minimal zoom for maneuvers to be visible. Default: null
setOutlineColor(Color outlineColor) → void
Color of the arrow's outline. Default: RGBA 0x000000FF.
setOutlineWidth({StylingProportionFunction outlineWidth = const mapkit_styling_proportion_function.StylingProportionFunction.fromFloat(0.0)}) → void
Width of the arrow's outline in units. Default: 0
setTriangleHeight({StylingProportionFunction triangleHeight = const mapkit_styling_proportion_function.StylingProportionFunction.fromFloat(24.0)}) → void
Height of the arrow tip in units. Default: 24
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited