GeoObjectTapEvent class abstract

Information about the tapped object.

Implemented types

Constructors

GeoObjectTapEvent()

Properties

geoObject → GeoObject
Return GeoObject The object that was tapped.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited