Geometry class final

A container of other geometry objects. Point - A point on the map. Polyline - A polyline between a number of points. Polygon - A polygon with one or more polygons in it. BoundingBox - A rectangular box around the object. Circle - A circle around the specified point.

Constructors

Geometry.fromBoundingBox(BoundingBox boundingBox)
const
Geometry.fromCircle(Circle circle)
const
Geometry.fromMultiPolygon(MultiPolygon multiPolygon)
const
Geometry.fromPoint(Point point)
const
Geometry.fromPolygon(Polygon polygon)
const
Geometry.fromPolyline(Polyline polyline)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asBoundingBox() → BoundingBox?
asCircle() → Circle?
asMultiPolygon() → MultiPolygon?
asPoint() → Point?
asPolygon() → Polygon?
asPolyline() → Polyline?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when({required void onPoint(Point value), required void onPolyline(Polyline value), required void onPolygon(Polygon value), required void onMultiPolygon(MultiPolygon value), required void onBoundingBox(BoundingBox value), required void onCircle(Circle value)}) → void
Applies the passed function to the variant value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited