ImageImageSize class final

Available extensions

Constructors

ImageImageSize({required String size, int? width, int? height})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
height → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → String
final
width → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant ImageImageSize other) → bool
The equality operator.
override