LocationError class abstract final

Implemented types

Constructors

LocationError(Range lateralErrorRange, Range longitudinalErrorRange)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
lateralErrorRange → Range
The error of spreading locations across the route.
no setter
longitudinalErrorRange → Range
The error of spreading locations along the route.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant LocationError other) → bool
The equality operator.
override