LocationManagerUtils class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

lastKnownLocation Location?
Last known location, if one was ever received.
no setter

Static Methods

isPredictionSpoofingCleanerEnabled() bool
Returns the current value of the process-wide setting for prediction-based GNSS spoofing filtering. The setting is true by default.
setPredictionSpoofingCleanerEnabled(bool enabled) → void
Enables or disables prediction-based GNSS spoofing filtering. The filtering is enabled by default. This process-wide setting takes effect immediately for active location subscriptions.