LogoAlignment class final

Logo alignment class.

Available extensions

Constructors

LogoAlignment(LogoHorizontalAlignment horizontalAlignment, LogoVerticalAlignment verticalAlignment)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
horizontalAlignment → LogoHorizontalAlignment
Defines horizontal alignment.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticalAlignment → LogoVerticalAlignment
Defines vertical alignment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant LogoAlignment other) → bool
The equality operator.
override