Projection class abstract

Makes two conversions: world->XY and XY->world, where XY are tile indexes. There are two main derived classes: spherical mercator (google, osm) and wgs84 mercator (yandex).

Implemented types

Constructors

Projection()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
worldToXY(Point geoPoint, {required int zoom}) → XYPoint
Converts the world coordinates to a flat world position.
xyToWorld(XYPoint xyPoint, {required int zoom}) → Point
Converts the flat world position to world coordinates.

Operators

operator ==(Object other) → bool
The equality operator.
inherited