SpannableStringSpan class final

A span of text in the SpannableString.

Available extensions

Constructors

SpannableStringSpan({required int begin, required int end})
const

Properties

begin → int
The index of the beginning symbol of the span.
final
end → int
The index of the ending symbol of the span.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SpannableStringSpan other) → bool
The equality operator.
override