StylingLinearTiltFunctionPoints class abstract final

Implemented types

Constructors

StylingLinearTiltFunctionPoints(List<Point<double>> points)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
points → List<Point<double>>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant StylingLinearTiltFunctionPoints other) → bool
The equality operator.
override