StylingProportionFunction class final

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asBilinearFunctionMatrix() → StylingBilinearFunctionMatrix?
asFloat() → double?
asLinearTiltFunctionPoints() → StylingLinearTiltFunctionPoints?
asLinearZoomFunctionPoints() → StylingLinearZoomFunctionPoints?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when({required void onFloat(double value), required void onLinearZoomFunctionPoints(StylingLinearZoomFunctionPoints value), required void onLinearTiltFunctionPoints(StylingLinearTiltFunctionPoints value), required void onBilinearFunctionMatrix(StylingBilinearFunctionMatrix value)}) → void
Applies the passed function to the variant value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited