TimeInterval class abstract final

Implemented types

Constructors

TimeInterval(Duration from, Duration to)
factory

Properties

from → Duration
Lower limit in milliseconds.
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → Duration
Upper limit in milliseconds.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant TimeInterval other) → bool
The equality operator.
override