ZoomRangeIdl class final

Describes the range of zoom levels. Zooming is allowed between zMin and zMax values.

Available extensions

Constructors

ZoomRangeIdl({required int zMin, required int zMax})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zMax → int
Upper limit of zoom range, exclusive.
final
zMin → int
Lower limit of zoom range, inclusive.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant ZoomRangeIdl other) → bool
The equality operator.
override