DataProviderWithId class abstract

Provides any data.

Constructors

DataProviderWithId()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

load() → Future<ByteBuffer>
Returns data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
providerId() → String
Use the same id for the identical data, to prevent repeated loading of the same data into RAM and VRAM.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited