ExperimentData class final

Available extensions

Constructors

ExperimentData({required int testId, required int userGroup, required int userBucket})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testId → int
final
userBucket → int
final
userGroup → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant ExperimentData other) → bool
The equality operator.
override