I18nManagerFactory class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getI18nManagerInstance() → I18nManager
Gets the internationalization manager interface.
getLocale() → String
Returns the locale currently used by the runtime. Should be called only after locale has been set.
setLocale(String? locale) → void
Sets the application's locale. Useful only if MapKit is not used by the application. Otherwise, use {@code mapkit.MapKitFactory.setLocale()}. Also useless if someone else has already set the locale (produses warning and does nothing). Can be set to none, in this case system locale will be used.