LogMessage class final

Represents a log message with its metadata.

Available extensions

Constructors

LogMessage(DateTime time, LogMessageLogLevel level, {required String scope, required String message, required String verboseInfo})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
level → LogMessageLogLevel
Severity level of the log message.
final
message → String
The log message content.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
Scope or category of the log message.
final
time → DateTime
Absolute timestamp of the log message.
final
verboseInfo → String
Additional verbose information about the log message. Used for logging exceptions with call stack.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant LogMessage other) → bool
The equality operator.
override