SearchToponymObjectMetadata class abstract final

Additional data for toponym objects.

Inheritance
Implemented types

Constructors

SearchToponymObjectMetadata(SearchAddress address, SearchPrecision? precision, String? formerName, Point balloonPoint, int geoId, String? id)
factory

Properties

address → SearchAddress
Structured toponym address
no setter
balloonPoint → Point
Point where balloon for the toponym should be shown. Differs for direct and reverse search modes: Direct mode -- toponym center. Reverse mode -- toponym nearest point to the given coordinates.
no setter
formerName → String?
Former name for toponym if any.
no setter
geoId → int
geobase id
no setter
hashCode → int
The hash code for this object.
no setteroverride
id → String?
Persistent toponym id (available for Yandex-owned regions).
no setter
precision → SearchPrecision?
Toponym precision.
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchToponymObjectMetadata other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<SearchToponymObjectMetadata>
final