The class does not retain the object in the 'addressBookListener' parameter.
It is your responsibility to maintain a strong reference to
the target object while it is attached to a class.
The class does not retain the object in the 'addressBookListener' parameter.
It is your responsibility to maintain a strong reference to
the target object while it is attached to a class.
Request to attempt to get address book from server. Refresh attempts
may be throttled and ignored. Immediately after downloading from
disk, the first attempt to update will be made automatically.