Account class abstract

Constructors

Account()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

httpAuth(String token) String?
Creates the HTTP authorization header for requests. return null if default authorization needed ('OAuth token').
invalidateToken(String token) → void
Invalidates the OAuth token for an active account. The next token request occurs on a new OAuth token request from XToken.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestToken(TokenListener tokenListener) → void
Makes a token request for the provider. This method may be called often (per each request). For best perfomance your implementation should cache the token. See TokenListener for additional information.
toString() String
A string representation of this object.
inherited
uid() String
Get the user's UID

Operators

operator ==(Object other) bool
The equality operator.
inherited